==> toutdoux-1.2.4.tar.gz: ToutDoux-1.2.4/core-plugins/help_doc/main.h <==
/*****************************************************************************/
/* main.h : Donnes globales et fentre principale
 * main.h : Global data and main window
 *
 *
 * Greffon ToutDoux : prestro & faq
 * ToutDoux's plug-in : prestro & faq
 * Copyright (c) 2000 Philippe Roy
 * Auteur - Author : Philippe Roy <ph_roy@yahoo.com>
 *
 *
 * Ce programme est un logiciel libre ; vous pouvez le redistribuer et/ou le modifier
 * sous les termes de la licence publique gnrale GNU telle qu'elle est publie par
 * la Free Software Foundation ; soit la version 2 de la licence, ou
 * (comme vous voulez) toute version ultrieure.
 *
 * Ce programme est distribu dans l'espoir qu'il sera utile,
 * mais SANS AUCUNE GARANTIE ; mme sans la garantie de
 * COMMERCIALIT ou d'ADQUATION A UN BUT PARTICULIER. Voir la
 * licence publique gnrale GNU pour plus de dtails.
 *
 * Vous devriez avoir reu une copie de la licence publique gnrale GNU
 * avec ce programme ; si ce n'est pas le cas, crivez  la Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
/*****************************************************************************/

/*****************************************************************************/
/* Variables globales */
/*****************************************************************************/
GtkObject *mod; /* Module */
GtkObject *flower[2]; /* Fichier support */

/*****************************************************************************/
/* Module */
/*****************************************************************************/
GtkObject *plugins_about_def (void);
void mod_about (void);
GtkObject *mod_def (void);
void plugins_show (gboolean exist);
void plugins_hide (void);
void plugins_destroy (void);

/*****************************************************************************/
/* Barre d'outils */
/*****************************************************************************/
void radiobutton1_clicked (GtkRadioButton *radiobutton, gpointer *user_data);
void radiobutton2_clicked (GtkRadioButton *radiobutton, gpointer *user_data);

==> toutdoux-1.2.7.tar.gz: ToutDoux-1.2.7/core-plugins/help_doc/main.h <==
/*****************************************************************************/
/* main.h : Donnes globales et fentre principale
 * main.h : Global data and main window
 *
 *
 * Greffon ToutDoux : prestro & faq
 * ToutDoux's plug-in : prestro & faq
 * Copyright (c) 2000-2001 Philippe Roy
 * Auteur - Author : Philippe Roy <ph_roy@toutdoux.org>
 *
 *
 * Ce programme est un logiciel libre ; vous pouvez le redistribuer et/ou le modifier
 * sous les termes de la licence publique gnrale GNU telle qu'elle est publie par
 * la Free Software Foundation ; soit la version 2 de la licence, ou
 * (comme vous voulez) toute version ultrieure.
 *
 * Ce programme est distribu dans l'espoir qu'il sera utile,
 * mais SANS AUCUNE GARANTIE ; mme sans la garantie de
 * COMMERCIALIT ou d'ADQUATION A UN BUT PARTICULIER. Voir la
 * licence publique gnrale GNU pour plus de dtails.
 *
 * Vous devriez avoir reu une copie de la licence publique gnrale GNU
 * avec ce programme ; si ce n'est pas le cas, crivez  la Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
/*****************************************************************************/

/*****************************************************************************/
/*** Module */
/*****************************************************************************/
GtkObject *plugins_about_def (void);
GtkObject *mod_def (GtkObject *mod);
void plugins_init (void);
void plugins_destroy (gpointer user_data);
void plugins_create (GtkObject *mod);

/*****************************************************************************/
/*** Barre d'outils - Tools barr */
/*****************************************************************************/
void radiobutton1_clicked (GtkRadioButton *radiobutton, GtkObject *mod);
void radiobutton2_clicked (GtkRadioButton *radiobutton, GtkObject *mod);

/*****************************************************************************/
/*** Fichier - File */
/*****************************************************************************/
void load (GtkObject *presto_browser, GtkObject *mod);
